aboutsummaryrefslogtreecommitdiff
path: root/qa/rpc-tests/rpcbind_test.py
diff options
context:
space:
mode:
authorMarcoFalke <falke.marco@gmail.com>2016-09-21 21:01:42 +0200
committerMarcoFalke <falke.marco@gmail.com>2016-09-21 21:19:20 +0200
commitddddaafa4aca2725a18606a38c3341a8637b0c3b (patch)
tree82e2ab4b32c6e1ca1d059cacf64ebb975f623e7d /qa/rpc-tests/rpcbind_test.py
parentcf5ebaa921a939cc3a81948a559c1f1ab53d68b6 (diff)
downloadbitcoin-ddddaafa4aca2725a18606a38c3341a8637b0c3b.tar.xz
[rpc] Deprecate getinfo
This was replaced by getmininginfo, getnetworkinfo and getwalletinfo
Diffstat (limited to 'qa/rpc-tests/rpcbind_test.py')
-rwxr-xr-xqa/rpc-tests/rpcbind_test.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/qa/rpc-tests/rpcbind_test.py b/qa/rpc-tests/rpcbind_test.py
index 3ac32140ba..144c2f4cd4 100755
--- a/qa/rpc-tests/rpcbind_test.py
+++ b/qa/rpc-tests/rpcbind_test.py
@@ -44,7 +44,7 @@ class RPCBindTest(BitcoinTestFramework):
def run_allowip_test(self, allow_ips, rpchost, rpcport):
'''
Start a node with rpcwallow IP, and request getinfo
at a non-localhost IP.
'''
base_args = ['-disablewallet', '-nolisten'] + ['-rpcallowip='+x for x in allow_ips]
@@ -52,7 +52,7 @@ class RPCBindTest(BitcoinTestFramework):
try:
# connect to node through non-loopback interface
node = get_rpc_proxy(rpc_url(0, "%s:%d" % (rpchost, rpcport)), 0)
- node.getinfo()
+ node.getnetworkinfo()
finally:
node = None # make sure connection will be garbage collected and closed
stop_nodes(self.nodes)
@@ -44,7 +44,7 @@ class RPCBindTest(BitcoinTestFramework):
def run_allowip_test(self, allow_ips, rpchost, rpcport):
'''
- Start a node with rpcwallow IP, and request getinfo
+ Start a node with rpcwallow IP, and request getnetworkinfo
at a non-localhost IP.
'''